.. Network Wrangler documentation master file, created by
   sphinx-quickstart on Mon May 13 22:23:51 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Network Wrangler's documentation!
============================================

.. note::  This documentation is based on the master branch

Objectives
------------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   design
   autodoc
   contributing




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
